about summary refs log tree commit diff
diff options
context:
space:
mode:
authorScott Mabin <scott@mabez.dev>2022-02-22 10:44:56 +0000
committerScott Mabin <scott@mabez.dev>2022-02-23 13:11:26 +0000
commit65614e91ad847e3d2941e1308bb2b1d916eba25f (patch)
treeb125cb7d217596f52ab74cd6aa73733e48c57c45
parentc651ba8a542c7d89b271efbf024a31091c824f4b (diff)
downloadrust-65614e91ad847e3d2941e1308bb2b1d916eba25f.tar.gz
rust-65614e91ad847e3d2941e1308bb2b1d916eba25f.zip
riscv32imc_esp_espidf: set max_atomic_width to 64
-rw-r--r--compiler/rustc_target/src/spec/riscv32imc_esp_espidf.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/rustc_target/src/spec/riscv32imc_esp_espidf.rs b/compiler/rustc_target/src/spec/riscv32imc_esp_espidf.rs
index fb084afe960..d506e7f6aac 100644
--- a/compiler/rustc_target/src/spec/riscv32imc_esp_espidf.rs
+++ b/compiler/rustc_target/src/spec/riscv32imc_esp_espidf.rs
@@ -18,11 +18,11 @@ pub fn target() -> Target {
             cpu: "generic-rv32".to_string(),
 
             // While the RiscV32IMC architecture does not natively support atomics, ESP-IDF does support
             // the __atomic* and __sync* GCC builtins, so setting `max_atomic_width` to `Some(32)`
             // and `atomic_cas` to `true` will cause the compiler to emit libcalls to these builtins.
             //
             // Support for atomics is necessary for the Rust STD library, which is supported by the ESP-IDF framework.
-            max_atomic_width: Some(32),
+            max_atomic_width: Some(64),
             atomic_cas: true,
 
             features: "+m,+c".to_string(),
@@ -18,11 +18,11 @@ pub fn target() -> Target {
 
             // While the RiscV32IMC architecture does not natively support atomics, ESP-IDF does support
-            // the __atomic* and __sync* GCC builtins, so setting `max_atomic_width` to `Some(32)`
+            // the __atomic* and __sync* GCC builtins, so setting `max_atomic_width` to `Some(64)`
             // and `atomic_cas` to `true` will cause the compiler to emit libcalls to these builtins.
             //